pub struct MessageVersion {
pub serial: Serial,
pub timestamp: Timestamp,
pub client_id: Option<String>,
pub description: Option<String>,
pub metadata: Option<BTreeMap<String, String>>,
}Expand description
Details of the latest create/update/delete version of a message.
Fields
serial: SerialUnique identifier of this message version.
timestamp: TimestampMilliseconds since the Unix epoch at which this version was created.
client_id: Option<String>Client ID of the user who performed the update or deletion.
description: Option<String>Optional description supplied with an update or deletion.
metadata: Option<BTreeMap<String, String>>Optional metadata supplied with an update or deletion.